You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@jmeter.apache.org by se...@apache.org on 2013/10/04 21:40:44 UTC

svn commit: r1529274 - in /jmeter/trunk: src/core/org/apache/jmeter/resources/ src/protocol/http/org/apache/jmeter/protocol/http/proxy/ xdocs/ xdocs/usermanual/

Author: sebb
Date: Fri Oct  4 19:40:43 2013
New Revision: 1529274

URL: http://svn.apache.org/r1529274
Log:
Rename HTTP Proxy Server as HTTP(S) Test Script Recorder
Bugzilla Id: 55626

Added:
    jmeter/trunk/xdocs/Copy (2) of changes.xml   (with props)
    jmeter/trunk/xdocs/Copy of changes.xml   (with props)
Modified:
    jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties
    jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Daemon.java
    jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Proxy.java
    jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java
    jmeter/trunk/xdocs/changes.xml
    jmeter/trunk/xdocs/usermanual/best-practices.xml
    jmeter/trunk/xdocs/usermanual/component_reference.xml
    jmeter/trunk/xdocs/usermanual/get-started.xml
    jmeter/trunk/xdocs/usermanual/index.xml
    jmeter/trunk/xdocs/usermanual/test_plan.xml

Modified: jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties (original)
+++ jmeter/trunk/src/core/org/apache/jmeter/resources/messages.properties Fri Oct  4 19:40:43 2013
@@ -734,7 +734,7 @@ proxy_sampler_type=Type\:
 proxy_separators=Add Separators
 proxy_target=Target Controller\:
 proxy_test_plan_content=Test plan content
-proxy_title=HTTP Proxy Server
+proxy_title=HTTP(S) Test Script Recorder
 pt_br=Portugese (Brazilian)
 ramp_up=Ramp-Up Period (in seconds)\:
 random_control_title=Random Controller

Modified: jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Daemon.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Daemon.java?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Daemon.java (original)
+++ jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Daemon.java Fri Oct  4 19:40:43 2013
@@ -135,9 +135,9 @@ public class Daemon extends Thread imple
                     // told to stop running.
                 }
             }
-            log.info("Proxy Server stopped");
+            log.info("HTTP(S) Test Script Recorder stopped");
         } catch (Exception e) {
-            log.warn("Proxy Server stopped", e);
+            log.warn("HTTP(S) Test Script Recorder stopped", e);
         } finally {
             JOrphanUtils.closeQuietly(mainSocket);
         }

Modified: jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Proxy.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Proxy.java?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Proxy.java (original)
+++ jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/Proxy.java Fri Oct  4 19:40:43 2013
@@ -242,7 +242,7 @@ public class Proxy extends Thread {
             log.error(port + "Not implemented (probably used https)", e);
             writeErrorToClient(HttpReplyHdr.formNotImplemented("Probably used https instead of http. " +
                     "To record https requests, see " +
-                    "<a href=\"http://jmeter.apache.org/usermanual/component_reference.html#HTTP_Proxy_Server\">HTTP Proxy Server documentation</a>"));
+                    "<a href=\"http://jmeter.apache.org/usermanual/component_reference.html#HTTP(S)_Test_Script_Recorder\">HTTP(S) Test Script Recorder documentation</a>"));
             result = generateErrorResult(result, request, e); // Generate result (if nec.) and populate it
         } catch (Exception e) {
             log.error(port + "Exception when processing sample", e);

Modified: jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java
URL: http://svn.apache.org/viewvc/jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/xdocs/Copy (2) of changes.xml (added)
+++ jmeter/trunk/xdocs/Copy (2) of changes.xml Fri Oct  4 19:40:43 2013
@@ -0,0 +1,509 @@
+<?xml version="1.0"?> 
+<!--
+   Licensed to the Apache Software Foundation (ASF) under one or more
+   contributor license agreements.  See the NOTICE file distributed with
+   this work for additional information regarding copyright ownership.
+   The ASF licenses this file to You under the Apache License, Version 2.0
+   (the "License"); you may not use this file except in compliance with
+   the License.  You may obtain a copy of the License at
+ 
+       http://www.apache.org/licenses/LICENSE-2.0
+ 
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+-->
+<document>   
+<properties>     
+    <author email="dev AT jmeter.apache.org">JMeter developers</author>     
+    <title>Changes</title>   
+</properties> 
+<body> 
+<section name="Changes"> 
+<style type="text/css"><!--
+h2 { color: #960000; }
+h3 { color: #960000; }
+--></style>
+<note>
+<b>This page details the changes made in the current version only.</b>
+<br></br>
+Earlier changes are detailed in the <a href="changes_history.html">History of Previous Changes</a>.
+</note>
+
+
+<!--  =================== 2.10 =================== -->
+
+<h1>Version 2.10</h1>
+
+<h2>New and Noteworthy</h2>
+
+<h3><u>Core Improvements:</u></h3>
+
+<h4>* New Performance improvements</h4>
+<p>
+<ul>
+<li>A Huge performance improvement has been made on High Throughput Tests (no pause), see <bugzilla>54777</bugzilla></li>
+<li>An issue with abusive SSL Context reset has been fixed which improves performances of pure HTTP tests, see <bugzilla>55023</bugzilla></li>
+</ul>
+</p>
+
+<h4>* New CSS/JQuery Tester in View Tree Results that makes CSS/JQuery Extractor a first class
+citizen in JMeter, you can now test your expressions very easily</h4>
+<p>
+<figure width="1144" height="638" image="changes/2.10/01_css_jquery_tester.png"></figure>
+</p>
+
+<h4>* Many improvements in HTTP Recording (JMeter Proxy Server) have been made</h4>
+<p><ul>
+<li>Better recording of HTTPS sites, embedded resources using subdomains will more easily be recorded when using JDK 7</li>
+<li>Redirection are now more smartly detected by HTTP Proxy Server, see <bugzilla>55531</bugzilla></li>
+<li>Many fixes on edgy cases with HTTPS have been made, see <bugzilla>55502</bugzilla>, <bugzilla>55504</bugzilla>, <bugzilla>55506</bugzilla></li>
+<li>Many fixes on edgy encoding have been made, see <bugzilla>54482</bugzilla>, <bugzilla>54142</bugzilla>, <bugzilla>54293</bugzilla></li>
+</ul>
+</p>
+
+<h4>* You can now load test MongoDB through new MongoDB Source Config</h4>
+<p>
+<figure width="912" height="486" image="changes/2.10/02_mongodb_source_config.png"></figure>
+</p>
+<p>
+<figure width="850" height="687" image="changes/2.10/14_mongodb_jsr223.png"></figure>
+</p>
+
+<h4>* Kerberos authentication has been added to Auth Manager</h4>
+<p>
+<figure width="1005" height="364" image="changes/2.10/15_kerberos.png"></figure>
+</p>
+
+<h4>* device can now be used in addition to source IP address</h4>
+
+<p>
+<figure width="1087" height="699" image="changes/2.10/16_device.png"></figure>
+</p>
+
+<h4>* You can now do functional testing of MongoDB scripts through new MongoDB Script</h4>
+<p>
+<figure width="906" height="313" image="changes/2.10/03_mongodb_script_alpha.png"></figure>
+</p>
+
+<h4>* Timeout has been added to OS Process Sampler</h4>
+<p>
+<figure width="684" height="586" image="changes/2.10/17_os_process_timeout.png"></figure>
+</p>
+
+<h4>* Query timeout has been added to JDBC Request</h4>
+<p>
+<figure width="540" height="600" image="changes/2.10/04_jdbc_request_timeout.png"></figure>
+</p>
+
+<h4>* New functions (__urlencode and __urldecode) are now available to encode/decode URL encoded chars</h4>
+<p>
+<figure width="512" height="240" image="changes/2.10/05_urlencode_function.png"></figure>
+</p>
+
+<h4>* Continuous Integration is now eased by addition of a new flag that forces NON-GUI JVM to exit after test end</h4>
+<p>See jmeter property:</p>
+<code>jmeterengine.force.system.exit</code>
+
+<h4>* HttpSampler now allows DELETE Http Method to have a body (works for HC4 and HC31 implementations). This allows for example to test Elastic Search APIs</h4>
+<p>
+<figure width="573" height="444" image="changes/2.10/06_http_request_delete_method.png"></figure>
+</p>
+
+<h4>* Distributed testing has been improved</h4>
+<p>
+<ul>
+<li>
+Number of threads on each node are now reported to controller.
+<p>
+<figure width="988" height="355" image="changes/2.10/17_threads_summariser.png"></figure>
+</p>
+<p>
+<figure width="125" height="33" image="changes/2.10/17_threads_gui.png"></figure>
+</p>
+
+</li>
+<li>Performance improvement on BatchSampleSender(<bugzilla>55423</bugzilla>)</li>
+<li>Addition of 2 SampleSender modes (StrippedAsynch and StrippedDiskStore), see jmeter.properties</li>
+</ul>
+</p>
+
+<h4>* ModuleController has been improved to better handle changes to referenced controllers</h4>
+
+<h4>* Improved class loader configuration, see <bugzilla>55503</bugzilla></h4>
+<p>
+<ul>
+<li>New property "plugin_dependency_paths" for plugin dependencies</li>
+<li>Properties "search_paths", "user.classpath" and "plugin_dependency_paths"
+    now automatically add all jars from configured directories</li>
+</ul>
+</p>
+
+<h4>* Best-practices section has been improved, ensure you read it to get the most out of JMeter</h4>
+
+<h3><u>GUI and ergonomy Improvements:</u></h3>
+
+
+<h4>* New Templates feature that allows you to create test plan from existing template or merge
+template into your Test Plan</h4>
+<p>
+<figure width="428" height="130" image="changes/2.10/07_jmeter_templates_icon.png"></figure>
+</p>
+<p>
+<figure width="781" height="472" image="changes/2.10/08_jmeter_templates_box.png"></figure>
+</p>
+
+<h4>* Workbench can now be saved</h4>
+<p>
+<figure width="489" height="198" image="changes/2.10/09_save_workbench.png"></figure>
+</p>
+
+<h4>* Syntax color has been added to scripts elements (BeanShell, BSF, and JSR223), MongoDB and JDBC elements making code much more readable and allowing <b>UNDO/REDO</b> through CTRL+Z/CTRL+Y</h4>
+<p>BSF Sampler with syntax color
+<figure width="915" height="620" image="changes/2.10/10_color_syntax_bsf_sampler.png"></figure>
+</p>
+<p>JSR223 Pre Processor with syntax color
+<figure width="911" height="614" image="changes/2.10/11_color_syntax_jsr223_preprocessor.png"></figure>
+</p>
+
+<h4>* Better editors are now available for Test Elements with large text content, like HTTP Sampler, and JMS related Test Element providing line numbering and allowing <b>UNDO/REDO</b> through CTRL+Z/CTRL+Y</h4>
+
+<h4>* JMeter GUI can now be fully Internationalized, all remaining issues have been fixed</h4>
+<h5>Currently French has all its labels translated. Other languages are partly translated, feel free to 
+contribute translations by reading <a href="localising/index.html">Localisation (Translator's Guide)</a></h5>
+
+<h4>* Moving elements in Test plan has been improved in many ways</h4>
+<h5>Drag and drop of elements in Test Plan tree is now much easier and possible on multiple nodes</h5>
+<p>
+<figure width="894" height="236" image="changes/2.10/12_drap_n-drop_multiple.png"></figure>
+</p>
+<p>
+<b>Note that due to this <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6560955">bug in Java</a>,
+you cannot drop a node after last node. The workaround is to drop it before this last node and then Drag and Drop the last node 
+before the one you just dropped.</b>
+</p>
+<h5>New shortcuts have been added to move elements in the tree. </h5>
+<p>(alt + Arrow Up) and (alt + Arrow Down) move the element within the parent node.<br/>
+(alt + Arrow Left) and (alt + Arrow Right) move the element up and down in the tree depth</p>
+
+<h4>* Response Time Graph Y axis can now be scaled</h4>
+<p>
+<figure width="947" height="596" image="changes/2.10/13_response_time_graph_y_scale.png"></figure>
+</p>
+
+<h4>* JUnit Sampler gives now more details on configuration errors</h4>
+
+<!--  =================== Known bugs =================== -->
+
+<h2>Known bugs</h2>
+
+<ul>
+<li>The Once Only controller behaves correctly under a Thread Group or Loop Controller,
+but otherwise its behaviour is not consistent (or clearly specified).</li>
+
+<li>Listeners don't show iteration counts when a If Controller has a condition which is always false from the first iteration (see <bugzilla>52496</bugzilla>).  
+A workaround is to add a sampler at the same level as (or superior to) the If Controller.
+For example a Test Action sampler with 0 wait time (which doesn't generate a sample),
+or a Debug Sampler with all fields set to False (to reduce the sample size).
+</li>
+
+<li>Webservice sampler does not consider the HTTP response status to compute the status of a response, thus a response 500 containing a non empty body will be considered as successful, see <bugzilla>54006</bugzilla>.
+To workaround this issue, ensure you always read the response and add a Response Assertion checking text inside the response.
+</li>
+
+<li>
+The numbers that appear to the left of the green box are the number of active threads / total number of threads, 
+these only apply to a locally run test; they do not include any threads started on remote systems when using client-server mode, (see <bugzilla>54152</bugzilla>).
+</li>
+
+<li>
+Note that there is a <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6396599 ">bug in Java</a>
+on some Linux systems that manifests itself as the following error when running the test cases or JMeter itself:
+<pre>
+ [java] WARNING: Couldn't flush user prefs:
+ java.util.prefs.BackingStoreException:
+ java.lang.IllegalArgumentException: Not supported: indent-number
+</pre>
+This does not affect JMeter operation. This issue is fixed since Java 7b05.
+</li>
+
+<li>
+With Java 1.6 and Gnome 3 on Linux systems, the JMeter menu may not work correctly (shift between mouse's click and the menu). 
+This is a known Java bug (see  <bugzilla>54477 </bugzilla>). 
+A workaround is to use a Java 7 runtime (OpenJDK or Oracle JDK).
+</li>
+</ul>
+
+<!-- =================== Incompatible changes =================== -->
+
+<h2>Incompatible changes</h2>
+
+<p>SMTP Sampler now uses eml file subject if subject field is empty</p>
+
+<p>With this version autoFlush has been turned off on PrintWriter in charge of writing test results. 
+This results in improved throughput for intensive tests but can result in more test data loss in case
+of JMeter crash (very rare). To revert to previous behaviour set jmeter.save.saveservice.autoflush property to true. </p>
+
+<p>
+Shortcut for Function Helper Dialog is now CTRL+SHIFT+F1 (CMD + SHIFT + F1 for Mac OS).
+The original key sequence (Ctrl+F1) did not work in some locations (it is consumed by the Java Swing ToolTipManager).
+It was therefore necessary to change the shortcut.
+</p>
+
+<p>
+Webservice (SOAP) Request has been removed by default from GUI as Element is deprecated (use HTTP Sampler with Body Data), if you need to show it, see property not_in_menu in jmeter.properties
+</p>
+
+<p>
+Transaction Controller now sets Response Code of Generated Parent Sampler (if Generate Parent Sampler is checked) to response code of first failing child in case of failure of one of the children, in previous versions Response Code was empty.
+</p>
+
+<p>
+In previous versions, IncludeController could run Test Elements located inside a Thread Group, this behaviour which was not documented could result in weird behaviour, it has been removed in this version (see <bugzilla>55464</bugzilla>). 
+The correct way to include Test Elements is to use Test Fragment as stated in documentation of Include Controller.
+</p>
+
+<p>
+The retry count for the HttpClient 3.1 and HttpClient 4.x samplers has been changed to 0.
+Previously the default was 1, which could cause unexpected additional traffic.
+</p>
+
+<p>Starting with this version, the HTTP(S) Test Script Recorder tries to detect when a sample is the result of a previous
+redirect. If the current response is a redirect, JMeter will save the redirect URL. When the next request is received, 
+it is compared with the saved redirect URL and if there is a match, JMeter will disable the generated sample.
+To revert to previous behaviour, set the property <code>proxy.redirect.disabling=false</code>
+ </p>
+
+<p>__escapeOroRegexpChars function does not trim anymore the value when escaping it from ORO reserved characters (see <bugzilla>55328</bugzilla>)</p>
+
+<p>commons-lang-2.6.jar has been removed from embedded libraries in jmeter/lib folder. If you use any plugin or third-party code that depends on it, you need to add it in jmeter/lib folder</p>
+
+<!-- =================== Bug fixes =================== -->
+
+<h2>Bug fixes</h2>
+
+<h3>HTTP Samplers and Proxy</h3>
+<ul>
+<li><bugzilla>54627</bugzilla> - JMeter Proxy GUI: Type of sampler setting takes the whole screen when there are samplers with long names.</li>
+<li><bugzilla>54629</bugzilla> - HTMLParser does not extract &amp;lt;object&amp;gt; tag urls.</li>
+<li><bugzilla>55023</bugzilla> - SSL Context reuse feature (51380) adversely affects non-ssl request performance/throughput. based on analysis by Brent Cromarty (brent.cromarty at yahoo.ca)</li>
+<li><bugzilla>55092</bugzilla> - Log message "WARN - jmeter.protocol.http.sampler.HTTPSamplerBase: Null URL detected (should not happen)" displayed when embedded resource URL is malformed.</li>
+<li><bugzilla>55161</bugzilla> - Useless processing in SoapSampler.setPostHeaders. Contributed by Adrian Nistor (nistor1 at illinois.edu)</li>
+<li><bugzilla>54482</bugzilla> - HC fails to follow redirects with non-encoded chars.</li>
+<li><bugzilla>54142</bugzilla> - HTTP(S) Test Script Recorder throws an exception when path contains "|" character.</li>
+<li><bugzilla>55388</bugzilla> - HC3 does not allow IP Source field to override httpclient.localaddress.</li>
+<li><bugzilla>55450</bugzilla> - HEAD redirects should remain as HEAD</li>
+<li><bugzilla>55455</bugzilla> - HTTPS with HTTPClient4 ignores cps setting</li>
+<li><bugzilla>55502</bugzilla> - Proxy generates empty http:/ entries when recording</li>
+<li><bugzilla>55504</bugzilla> - Proxy incorrectly issues CONNECT requests when browser prompts for certificate override</li>
+<li><bugzilla>55506</bugzilla> - Proxy should deliver failed requests to any configured Listeners</li>
+<li><bugzilla>55545</bugzilla> - HTTP(S) Test Script Recorder GUI should not allow both Follow and Auto redirect to be selected</li>
+</ul>
+
+<h3>Other Samplers</h3>
+<ul>
+<li><bugzilla>54913</bugzilla> - JMSPublisherGui incorrectly restores its state. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>55027</bugzilla> - Test Action regression, duration value is not recorded (nightly build).</li>
+<li><bugzilla>55163</bugzilla> - BeanShellTestElement fails to quote string when calling testStarted(String)/testEnded(String).</li>
+<li><bugzilla>55349</bugzilla> - NativeCommand hangs if no input file is specified and the application requests input.</li>
+<li><bugzilla>55462</bugzilla> - System Sampler should not change the sampler label if a sample fails</li>
+</ul>
+
+<h3>Controllers</h3>
+<ul>
+<li><bugzilla>54467</bugzilla> - Loop Controller: compute loop value only once per parent iteration.</li>
+<li><bugzilla>54985</bugzilla> - Make Transaction Controller set Response Code of Generated Parent Sampler to response code of first failing child in case of failure of one of its children. Contributed by Mikhail Epikhin (epihin-m at yandex.ru)</li>
+<li><bugzilla>54950</bugzilla> - ModuleController : Changes to referenced Module are not taken into account if changes occur after first run and referenced node is disabled.</li>
+<li><bugzilla>55201</bugzilla> - ForEach controller excludes start index and includes end index (clarified documentation).</li>
+<li><bugzilla>55334</bugzilla> - Adding Include Controller to test plan (made of Include Controllers) without saving TestPlan leads to included code not being taken into account until save.</li>
+<li><bugzilla>55375</bugzilla> -  StackOverflowError with ModuleController in Non-GUI mode if its name is the same as the target node.</li>
+<li><bugzilla>55464</bugzilla> - Include Controller running included thread group</li>
+</ul>
+
+<h3>Listeners</h3>
+<ul>
+<li><bugzilla>54589</bugzilla> - View Results Tree have a lot of Garbage characters if html page uses double-byte charset.</li>
+<li><bugzilla>54753</bugzilla> - StringIndexOutOfBoundsException at SampleResult.getSampleLabel() if key_on_threadname=false when using Statistical mode.</li>
+<li><bugzilla>54685</bugzilla> - ArrayIndexOutOfBoundsException if "sample_variable" is set in client but not server.</li>
+<li><bugzilla>55111</bugzilla> - ViewResultsTree: text not refitted if vertical scrollbar is required. Contributed by Milamber</li>
+</ul>
+
+<h3>Timers, Assertions, Config, Pre- &amp; Post-Processors</h3>
+<ul>
+<li><bugzilla>54540</bugzilla> - "HTML Parameter Mask" are not marked deprecated in the IHM.</li>
+<li><bugzilla>54575</bugzilla> - CSS/JQuery Extractor : Choosing JODD Implementation always uses JSOUP.</li>
+<li><bugzilla>54901</bugzilla> - Response Assertion GUI behaves weirdly.</li>
+<li><bugzilla>54924</bugzilla> - XMLAssertion uses JMeter JVM file.encoding instead of response encoding and does not clean threadlocal variable.</li>
+<li><bugzilla>53679</bugzilla> -  Constant Throughput Timer bug with localization. Reported by Ludovic Garcia</li>
+</ul>
+
+<h3>Functions</h3>
+<ul>
+<li><bugzilla>55328</bugzilla> - __escapeOroRegexpChars trims spaces.</li>
+</ul>
+
+<h3>I18N</h3>
+<ul>
+<li><bugzilla>55437</bugzilla> - ComboStringEditor does not translate EDIT and UNDEFINED strings on language change</li>
+<li><bugzilla>55501</bugzilla> - Incorrect encoding for French description of __char function. Contributed by Antonio Gomes Rodrigues (ra0077 at gmail.com)</li>
+</ul>
+
+<h3>General</h3>
+<ul>
+<li><bugzilla>54504</bugzilla> - Resource string not found: [clipboard_node_read_error].</li>
+<li><bugzilla>54538</bugzilla> - GUI: context menu is too big.</li>
+<li><bugzilla>54847</bugzilla> - Cut &amp; Paste is broken with tree multi-selection. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54870</bugzilla> - Tree drag and drop may lose leaf nodes (affected nightly build). Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>55056</bugzilla> - wasted work in Data.append(). Contributed by Adrian Nistor (nistor1 at illinois.edu)</li>
+<li><bugzilla>55129</bugzilla> -  Change Javadoc generation per CVE-2013-1571, VU#225657.</li>
+<li><bugzilla>55187</bugzilla> - Integer overflow when computing ONE_YEAR_MS in HTTP CacheManager.</li>
+<li><bugzilla>55208</bugzilla> - JSR223 language entries are duplicated; fold to lower case.</li>
+<li><bugzilla>55203</bugzilla> - TestBeanGUI - wrong language settings found.</li>
+<li><bugzilla>55065</bugzilla> - Useless processing in Spline3.converge(). Contributed by Adrian Nistor (nistor1 at illinois.edu)</li>
+<li><bugzilla>55064</bugzilla> - Useless processing in ReportTreeListener.isValidDragAction(). Contributed by Adrian Nistor (nistor1 at illinois.edu)</li>
+<li><bugzilla>55242</bugzilla> - BeanShell Client jar throws exceptions after upgrading to 2.8.</li>
+<li><bugzilla>55288</bugzilla> - JMeter should default to 0 retries for HTTP requests.</li>
+<li><bugzilla>55405</bugzilla> - ant download_jars task fails if lib/api or lib/doc are missing. Contributed by Antonio Gomes Rodrigues.</li>
+<li><bugzilla>55427</bugzilla> - TestBeanHelper should ignore properties not supported by GenericTestBeanCustomizer</li>
+<li><bugzilla>55459</bugzilla> - Elements using ComboStringEditor lose the input value if user selects another Test Element</li>
+<li><bugzilla>54152</bugzilla> - In distributed testing : activeThreads always show 0 in GUI and Summariser</li>
+<li><bugzilla>55509</bugzilla> - Allow Plugins to be notified of remote thread number progression</li>
+<li><bugzilla>55572</bugzilla> - Detail popup of parameter does not show a Scrollbar when content exceeds display</li>
+<li><bugzilla>55580</bugzilla> -  Help pane does not scroll to start for &lt;a href="#"&gt; links</li>
+<li><bugzilla>55600</bugzilla> - JSyntaxTextArea : Strange behaviour on first undo</li>
+</ul>
+
+<!-- =================== Improvements =================== -->
+
+<h2>Improvements</h2>
+
+<h3>HTTP Samplers and Proxy</h3>
+<ul>
+<li>HTTP Request: Small user interaction improvements in Row parameter Detail Box. Contributed by Milamber</li>
+<li><bugzilla>55255</bugzilla> - Allow Body in HTTP DELETE method to support API that use it (like ElasticSearch).</li>
+<li><bugzilla>53480</bugzilla> - Add Kerberos support to Http Sampler (HttpClient4). Based on patch by Felix Schumacher (felix.schumacher at internetallee.de)</li>
+<li><bugzilla>54874</bugzilla> - Support device in addition to source IP address. Based on patch by Dan Fruehauf (malkodan at gmail.com)</li>
+<li><bugzilla>55488</bugzilla> - Add .ico and .woff file extension to default suggested exclusions in proxy recorder. Contributed by Antonio Gomes Rodrigues</li>
+<li><bugzilla>55525</bugzilla> - Proxy should support alias for keyserver entry</li>
+<li><bugzilla>55531</bugzilla> - Proxy recording and redirects. Added code to disable redirected samples.</li>
+</ul>
+
+<h3>Other samplers</h3>
+<ul>
+<li><bugzilla>54788</bugzilla> - JMS Point-to-Point Sampler - GUI enhancements to increase readability and ease of use. Contributed by Bruno Antunes (b.m.antunes at gmail.com)</li>
+<li><bugzilla>54798</bugzilla> - Using subject from EML-file for SMTP Sampler. Contributed by Mikhail Epikhin (epihin-m at yandex.ru)</li>
+<li><bugzilla>54759</bugzilla> - SSLPeerUnverifiedException using HTTPS , property documented.</li>
+<li><bugzilla>54896</bugzilla> - JUnit sampler gives only "failed to create an instance of the class" message with constructor problems.</li>
+<li><bugzilla>55084</bugzilla> - Add timeout support for JDBC Request. Contributed by Mikhail Epikhin (epihin-m at yandex.ru)</li>
+<li><bugzilla>55403</bugzilla> - Enhancement to OS sampler: Support for timeout</li>
+<li><bugzilla>55518</bugzilla> - Add ability to limit number of cached PreparedStatements per connection when "Prepared Select Statement", "Prepared Update Statement" or "Callable Statement" query type is selected</li>
+</ul>
+
+<h3>Controllers</h3>
+<ul>
+<li><bugzilla>54271</bugzilla> - Module Controller breaks if test plan is renamed.</li>
+</ul>
+
+<h3>Listeners</h3>
+<ul>
+<li><bugzilla>54532</bugzilla> - Improve Response Time Graph Y axis scale with huge values or small values (&amp;lt; 1000ms). Add a new field to define increment scale. Contributed by Milamber based on patch by Luca Maragnani (luca.maragnani at gmail.com)</li>
+<li><bugzilla>54576</bugzilla> - View Results Tree : Add a CSS/JQuery Tester.</li>
+<li><bugzilla>54777</bugzilla> - Improve Performance of default ResultCollector. Based on patch by Mikhail Epikhin (epihin-m at yandex.ru)</li>
+<li><bugzilla>55389</bugzilla> - Show IP source address in request data</li>
+</ul>
+
+<h3>Timers, Assertions, Config, Pre- &amp; Post-Processors</h3>
+<ul>
+<li><bugzilla>54789</bugzilla> - XPath Assertion - GUI enhancements to increase readability and ease of use.</li>
+</ul>
+
+<h3>Functions</h3>
+<ul>
+<li><bugzilla>54991</bugzilla> - Add functions to encode/decode URL encoded chars (__urlencode and __urldecode). Contributed by Milamber.</li>
+</ul>
+
+<h3>I18N</h3>
+<ul>
+<li><bugzilla>55241</bugzilla> - Need GUI Editor to process fields which are based on Enums with localised display strings</li>
+<li><bugzilla>55440</bugzilla> - ComboStringEditor should allow tags to be language dependent</li>
+<li><bugzilla>55432</bugzilla> - CSV Dataset Config loses sharing mode when switching languages</li>
+</ul>
+
+<h3>General</h3>
+<ul>
+<li><bugzilla>54584</bugzilla> - MongoDB plugin. Based on patch by Jan Paul Ettles (janpaulettles at gmail.com)</li>
+<li><bugzilla>54669</bugzilla> - Add flag forcing non-GUI JVM to exit after test. Contributed by Scott Emmons</li>
+<li><bugzilla>42428</bugzilla> - Workbench not saved with Test Plan. Contributed by Dzmitry Kashlach (dzmitrykashlach at gmail.com)</li>
+<li><bugzilla>54825</bugzilla> - Add shortcuts to move elements in the tree. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54834</bugzilla> - Improve Drag &amp; Drop in the jmeter tree. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54839</bugzilla> - Set the application name on Mac. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54841</bugzilla> - Correctly handle the quit shortcut on Mac Os (CMD-Q). Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54844</bugzilla> - Set the application icon on Mac Os. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54864</bugzilla> - Enable multi selection drag &amp; drop in the tree without having to start dragging before releasing Shift or Control. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54945</bugzilla> - Add Shutdown Hook to enable trapping kill or CTRL+C signals.</li>
+<li><bugzilla>54990</bugzilla> - Download large files avoiding outOfMemory.</li>
+<li><bugzilla>55085</bugzilla> - UX Improvement : Ability to create New Test Plan from Templates. Contributed by UBIK Load Pack (support at ubikloadpack.com)</li>
+<li><bugzilla>55172</bugzilla> - Provide plugins a way to add Top Menu and menu items.</li>
+<li><bugzilla>55202</bugzilla> - Add syntax color for scripts elements (BeanShell, BSF, and JSR223) and JDBC elements with RSyntaxTextArea. Contributed by Milamber based on patch by Marko Vlahovic (vlahovic74 at gmail.com)</li>
+<li><bugzilla>55175</bugzilla> - HTTPHC4Impl refactoring to allow better inheritance.</li>
+<li><bugzilla>55236</bugzilla> - Templates - provide button to reload template details.</li>
+<li><bugzilla>55237</bugzilla> - Template system should support relative fileName entries.</li>
+<li><bugzilla>55423</bugzilla> - BatchSampleSender: Reduce locking granularity by moving listener.processBatch outside of synchronized block</li>
+<li><bugzilla>55424</bugzilla> - Add Stripping to existing SampleSenders</li>
+<li><bugzilla>55451</bugzilla> - Test Element GUI with JSyntaxTextArea scroll down when text content is long enough to add a Scrollbar</li>
+<li><bugzilla>55513</bugzilla> - StreamCopier cannot be used with System.err or System.out as it closes the output stream</li>
+<li><bugzilla>55514</bugzilla> - SystemCommand should support arbitrary input and output streams</li>
+<li><bugzilla>55515</bugzilla> - SystemCommand should support chaining of commands</li>
+<li><bugzilla>55606</bugzilla> - Use JSyntaxtTextArea for Http Request, JMS Test Elements</li>
+</ul>
+
+<h2>Non-functional changes</h2>
+<ul>
+<li>Updated to jsoup-1.7.2</li>
+<li><bugzilla>54776</bugzilla> - Update the dependency on Bouncy Castle to 1.48. Contributed by Emmanuel Bourg (ebourg at apache.org)</li>
+<li>Updated to HttpComponents Client 4.2.6 (from 4.2.3)</li>
+<li>Updated to HttpComponents Core 4.2.5 (from 4.2.3)</li>
+<li>Updated to commons-codec 1.8 (from 1.6)</li>
+<li>Updated to commons-io 2.4 (from 2.2)</li>
+<li>Updated to commons-logging 1.1.3 (from 1.1.1)</li>
+<li>Updated to commons-net 3.3 (from 3.1)</li>
+<li>Updated to jdom-1.1.3 (from 1.1.2)</li>
+<li>Updated to jodd-lagarto and jodd-core 3.4.4 (from 3.4.1)</li>
+<li>Updated to junit 4.11 (from 4.10)</li>
+<li>Updated to slf4j-api 1.7.5 (from 1.7.2)</li>
+<li>Updated to tika 1.4 (from 1.3)</li>
+<li>Updated to xmlgraphics-commons 1.5 (from 1.3.1)</li>
+<li>Updated to xstream 1.4.4 (from 1.4.2)</li>
+<li>Updated to BouncyCastle 1.49 (from 1.48)</li>
+<li><bugzilla>54912</bugzilla> - JMeterTreeListener should use constants. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54903</bugzilla> - Remove the dependency on the Activation Framework. Contributed by Emmanuel Bourg (ebourg at apache.org)</li>
+<li>Moved commons-lang (2.6) to lib/doc as it's only needed by Velocity.</li>
+<li>Re-organised and simplified NOTICE and LICENSE files.</li>
+<li><bugzilla>55411</bugzilla> -  NativeCommand could be useful elsewhere. Copied code to o.a.jorphan.exec.</li>
+<li><bugzilla>55435</bugzilla> - ComboStringEditor could be simplified to make most settings final</li>
+<li><bugzilla>55436</bugzilla> - ComboStringEditor should implement ClearGui</li>
+<li><bugzilla>55463</bugzilla> - Component.requestFocus() is discouraged; use requestFocusInWindow() instead</li>
+<li><bugzilla>55486</bugzilla> - New JMeter Logo. Contributed by UBIK Load Pack (support at ubikloadpack.com)</li>
+<li><bugzilla>55548</bugzilla> - Tidy up use of TestElement.ENABLED; use TestElement.isEnabled()/setEnabled() throughout</li>
+<li><bugzilla>55617</bugzilla> - Improvements to jorphan collection. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>55623</bugzilla> - Invalid/unexpected configuration values should not be silently ignored</li>
+</ul>
+
+<h2>Thanks</h2>
+<p>We thank all contributors mentioned in bug and improvement sections above.<br/>
+We also thank bug reporters who helped us improve JMeter. <br/>
+For this release we want to give special thanks to the following reporters for the clear reports and tests made after our fixes:
+<ul>
+<li>Immanuel Hayden (immanuel.hayden at gmail.com)</li>
+<li>Danny Lade (dlade at web.de)</li>
+<li>Brent Cromarty (brent.cromarty at yahoo.ca)</li>
+<li>Wolfgang Heider (wolfgang.heider at racon.at)</li>
+<li>Shmuel Krakower (shmulikk at gmail.com)</li>
+</ul>
+
+ </p>
+</section> 
+</body> 
+</document>

Propchange: jmeter/trunk/xdocs/Copy (2) of changes.xml
------------------------------------------------------------------------------
    svn:eol-style = native

Added: jmeter/trunk/xdocs/Copy of changes.xml
URL: http://svn.apache.org/viewvc/jmeter/trunk/xdocs/Copy%20of%20changes.xml?rev=1529274&view=auto
==============================================================================
--- jmeter/trunk/xdocs/Copy of changes.xml (added)
+++ jmeter/trunk/xdocs/Copy of changes.xml Fri Oct  4 19:40:43 2013
@@ -0,0 +1,504 @@
+<?xml version="1.0"?> 
+<!--
+   Licensed to the Apache Software Foundation (ASF) under one or more
+   contributor license agreements.  See the NOTICE file distributed with
+   this work for additional information regarding copyright ownership.
+   The ASF licenses this file to You under the Apache License, Version 2.0
+   (the "License"); you may not use this file except in compliance with
+   the License.  You may obtain a copy of the License at
+ 
+       http://www.apache.org/licenses/LICENSE-2.0
+ 
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
+-->
+<document>   
+<properties>     
+    <author email="dev AT jmeter.apache.org">JMeter developers</author>     
+    <title>Changes</title>   
+</properties> 
+<body> 
+<section name="Changes"> 
+<style type="text/css"><!--
+h2 { color: #960000; }
+h3 { color: #960000; }
+--></style>
+<note>
+<b>This page details the changes made in the current version only.</b>
+<br></br>
+Earlier changes are detailed in the <a href="changes_history.html">History of Previous Changes</a>.
+</note>
+
+
+<!--  =================== 2.10 =================== -->
+
+<h1>Version 2.10</h1>
+
+<h2>New and Noteworthy</h2>
+
+<h3><u>Core Improvements:</u></h3>
+
+<h4>* A Huge performance improvement has been made on High Throughput Tests (no pause), see <bugzilla>54777</bugzilla></h4>
+
+<h4>* New CSS/JQuery Tester in View Tree Results that makes CSS/JQuery Extractor a first class
+citizen in JMeter, you can now test your expressions very easily</h4>
+<p>
+<figure width="1144" height="638" image="changes/2.10/01_css_jquery_tester.png"></figure>
+</p>
+
+<h4>* Recording of HTTPS scripts is much easier</h4>
+<p>
+[Note: the HTTP Proxy Server has been renamed as the HTTP(S) Test Recorder]
+</p>
+<p>
+Previously, JMeter used a generic self-signed certificate to record HTTPS browser sessions. 
+The certificate was not specific to a host, and was not signed by a trusted Root CA, so browsers would prompt the user
+to accept the certificate each time a new host was encountered.
+This was awkward to use. But the main problem was that browsers do not prompt for embedded resources,
+so it did not work for 3rd party embedded HTTPS resources (e.g. images from a separate server).
+</p>
+
+<p>
+The HTTPS Test Recorder can now automatically generate a signed host certificate for each HTTPS host.
+To do this, it uses a locally generated Root CA certificate, unique to the JMeter installation.
+This is used to authenticate the host (or domain) certificates JMeter generates 
+</p>
+<h4>* You can now load test MongoDB through new MongoDB Source Config</h4>
+<p>
+<figure width="912" height="486" image="changes/2.10/02_mongodb_source_config.png"></figure>
+</p>
+<p>
+<figure width="850" height="687" image="changes/2.10/14_mongodb_jsr223.png"></figure>
+</p>
+
+<h4>* Kerberos authentication has been added to Auth Manager</h4>
+<p>
+<figure width="1005" height="364" image="changes/2.10/15_kerberos.png"></figure>
+</p>
+
+<h4>* device can now be used in addition to source IP address</h4>
+
+<p>
+<figure width="1087" height="699" image="changes/2.10/16_device.png"></figure>
+</p>
+
+<h4>* You can now do functional testing of MongoDB scripts through new MongoDB Script</h4>
+<p>
+<figure width="906" height="313" image="changes/2.10/03_mongodb_script_alpha.png"></figure>
+</p>
+
+<h4>* Timeout has been added to OS Process Sampler</h4>
+<p>
+<figure width="684" height="586" image="changes/2.10/17_os_process_timeout.png"></figure>
+</p>
+
+<h4>* Query timeout has been added to JDBC Request</h4>
+<p>
+<figure width="540" height="600" image="changes/2.10/04_jdbc_request_timeout.png"></figure>
+</p>
+
+<h4>* New functions (__urlencode and __urldecode) are now available to encode/decode URL encoded chars</h4>
+<p>
+<figure width="512" height="240" image="changes/2.10/05_urlencode_function.png"></figure>
+</p>
+
+<h4>* Continuous Integration is now eased by addition of a new flag that forces NON-GUI JVM to exit after test end</h4>
+<p>See jmeter property:</p>
+<code>jmeterengine.force.system.exit</code>
+
+<h4>* HttpSampler now allows DELETE Http Method to have a body (works for HC4 and HC31 implementations). This allows for example to test Elastic Search APIs</h4>
+<p>
+<figure width="573" height="444" image="changes/2.10/06_http_request_delete_method.png"></figure>
+</p>
+
+<h4>* Distributed testing has been improved</h4>
+<p>
+<ul>
+<li>
+Number of threads on each node are now reported to controller.
+<p>
+<figure width="988" height="355" image="changes/2.10/17_threads_summariser.png"></figure>
+</p>
+<p>
+<figure width="125" height="33" image="changes/2.10/17_threads_gui.png"></figure>
+</p>
+
+</li>
+<li>Performance improvement on BatchSampleSender(<bugzilla>55423</bugzilla>)</li>
+<li>Addition of 2 SampleSender modes (StrippedAsynch and StrippedDiskStore), see jmeter.properties</li>
+</ul>
+</p>
+
+<h4>* ModuleController has been improved to better handle changes to referenced controllers</h4>
+
+<h4>* Improved class loader configuration, see <bugzilla>55503</bugzilla></h4>
+<p>
+<ul>
+<li>New property "plugin_dependency_paths" for plugin dependencies</li>
+<li>Properties "search_paths", "user.classpath" and "plugin_dependency_paths"
+    now automatically add all jars from configured directories</li>
+</ul>
+</p>
+
+<h4>* Best-practices section has been improved, ensure you read it to get the most out of JMeter</h4>
+
+<h3><u>GUI and ergonomy Improvements:</u></h3>
+
+
+<h4>* New Templates feature that allows you to create test plan from existing template or merge
+template into your Test Plan</h4>
+<p>
+<figure width="428" height="130" image="changes/2.10/07_jmeter_templates_icon.png"></figure>
+</p>
+<p>
+<figure width="781" height="472" image="changes/2.10/08_jmeter_templates_box.png"></figure>
+</p>
+
+<h4>* Workbench can now be saved</h4>
+<p>
+<figure width="489" height="198" image="changes/2.10/09_save_workbench.png"></figure>
+</p>
+
+<h4>* Syntax color has been added to scripts elements (BeanShell, BSF, and JSR223), MongoDB and JDBC elements making code much more readable</h4>
+<p>BSF Sampler with syntax color
+<figure width="915" height="620" image="changes/2.10/10_color_syntax_bsf_sampler.png"></figure>
+</p>
+<p>JSR223 Pre Processor with syntax color
+<figure width="911" height="614" image="changes/2.10/11_color_syntax_jsr223_preprocessor.png"></figure>
+</p>
+
+<h4>* JMeter GUI can now be fully Internationalized, all remaining issues have been fixed</h4>
+<h5>Currently French has all its labels translated. Other languages are partly translated, feel free to 
+contribute translations by reading <a href="localising/index.html">Localisation (Translator's Guide)</a></h5>
+
+<h4>* Moving elements in Test plan has been improved in many ways</h4>
+<h5>Drag and drop of elements in Test Plan tree is now much easier and possible on multiple nodes</h5>
+<p>
+<figure width="894" height="236" image="changes/2.10/12_drap_n-drop_multiple.png"></figure>
+</p>
+<p>
+<b>Note that due to this <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6560955">bug in Java</a>,
+you cannot drop a node after last node. The workaround is to drop it before this last node and then Drag and Drop the last node 
+before the one you just dropped.</b>
+</p>
+<h5>New shortcuts have been added to move elements in the tree. </h5>
+<p>(alt + Arrow Up) and (alt + Arrow Down) move the element within the parent node.<br/>
+(alt + Arrow Left) and (alt + Arrow Right) move the element up and down in the tree depth</p>
+
+<h4>* Response Time Graph Y axis can now be scaled</h4>
+<p>
+<figure width="947" height="596" image="changes/2.10/13_response_time_graph_y_scale.png"></figure>
+</p>
+
+<h4>* JUnit Sampler gives now more details on configuration errors</h4>
+
+<!--  =================== Known bugs =================== -->
+
+<h2>Known bugs</h2>
+
+<ul>
+<li>The Once Only controller behaves correctly under a Thread Group or Loop Controller,
+but otherwise its behaviour is not consistent (or clearly specified).</li>
+
+<li>Listeners don't show iteration counts when a If Controller has a condition which is always false from the first iteration (see <bugzilla>52496</bugzilla>).  
+A workaround is to add a sampler at the same level as (or superior to) the If Controller.
+For example a Test Action sampler with 0 wait time (which doesn't generate a sample),
+or a Debug Sampler with all fields set to False (to reduce the sample size).
+</li>
+
+<li>Webservice sampler does not consider the HTTP response status to compute the status of a response, thus a response 500 containing a non empty body will be considered as successful, see <bugzilla>54006</bugzilla>.
+To workaround this issue, ensure you always read the response and add a Response Assertion checking text inside the response.
+</li>
+
+<li>
+The numbers that appear to the left of the green box are the number of active threads / total number of threads, 
+these only apply to a locally run test; they do not include any threads started on remote systems when using client-server mode, (see <bugzilla>54152</bugzilla>).
+</li>
+
+<li>
+Note that there is a <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6396599 ">bug in Java</a>
+on some Linux systems that manifests itself as the following error when running the test cases or JMeter itself:
+<pre>
+ [java] WARNING: Couldn't flush user prefs:
+ java.util.prefs.BackingStoreException:
+ java.lang.IllegalArgumentException: Not supported: indent-number
+</pre>
+This does not affect JMeter operation. This issue is fixed since Java 7b05.
+</li>
+
+<li>
+With Java 1.6 and Gnome 3 on Linux systems, the JMeter menu may not work correctly (shift between mouse's click and the menu). 
+This is a known Java bug (see  <bugzilla>54477 </bugzilla>). 
+A workaround is to use a Java 7 runtime (OpenJDK or Oracle JDK).
+</li>
+</ul>
+
+<!-- =================== Incompatible changes =================== -->
+
+<h2>Incompatible changes</h2>
+
+<p>SMTP Sampler now uses eml file subject if subject field is empty</p>
+
+<p>With this version autoFlush has been turned off on PrintWriter in charge of writing test results. 
+This results in improved throughput for intensive tests but can result in more test data loss in case
+of JMeter crash (very rare). To revert to previous behaviour set jmeter.save.saveservice.autoflush property to true. </p>
+
+<p>
+Shortcut for Function Helper Dialog is now CTRL+SHIFT+F1 (CMD + SHIFT + F1 for Mac OS).
+The original key sequence (Ctrl+F1) did not work in some locations (it is consumed by the Java Swing ToolTipManager).
+It was therefore necessary to change the shortcut.
+</p>
+
+<p>
+Webservice (SOAP) Request has been removed by default from GUI as Element is deprecated (use HTTP Sampler with Body Data), if you need to show it, see property not_in_menu in jmeter.properties
+</p>
+
+<p>
+Transaction Controller now sets Response Code of Generated Parent Sampler (if Generate Parent Sampler is checked) to response code of first failing child in case of failure of one of the children, in previous versions Response Code was empty.
+</p>
+
+<p>
+In previous versions, IncludeController could run Test Elements located inside a Thread Group, this behaviour which was not documented could result in weird behaviour, it has been removed in this version (see <bugzilla>55464</bugzilla>). 
+The correct way to include Test Elements is to use Test Fragment as stated in documentation of Include Controller.
+</p>
+
+<p>
+The retry count for the HttpClient 3.1 and HttpClient 4.x samplers has been changed to 0.
+Previously the default was 1, which could cause unexpected additional traffic.
+</p>
+
+<p>Starting with this version, the HTTP(S) Test Script Recorder tries to detect when a sample is the result of a previous
+redirect. If the current response is a redirect, JMeter will save the redirect URL. When the next request is received, 
+it is compared with the saved redirect URL and if there is a match, JMeter will disable the generated sample.
+To revert to previous behaviour, set the property <code>proxy.redirect.disabling=false</code>
+ </p>
+
+<p>__escapeOroRegexpChars function does not trim anymore the value when escaping it from ORO reserved characters (see <bugzilla>55328</bugzilla>)</p>
+
+<p>commons-lang-2.6.jar has been removed from embedded libraries in jmeter/lib folder. If you use any plugin or third-party code that depends on it, you need to add it in jmeter/lib folder</p>
+
+<!-- =================== Bug fixes =================== -->
+
+<h2>Bug fixes</h2>
+
+<h3>HTTP Samplers and Proxy</h3>
+<ul>
+<li><bugzilla>54627</bugzilla> - JMeter Proxy GUI: Type of sampler setting takes the whole screen when there are samplers with long names.</li>
+<li><bugzilla>54629</bugzilla> - HTMLParser does not extract &amp;lt;object&amp;gt; tag urls.</li>
+<li><bugzilla>55023</bugzilla> - SSL Context reuse feature (51380) adversely affects non-ssl request performance/throughput. based on analysis by Brent Cromarty (brent.cromarty at yahoo.ca)</li>
+<li><bugzilla>55092</bugzilla> - Log message "WARN - jmeter.protocol.http.sampler.HTTPSamplerBase: Null URL detected (should not happen)" displayed when embedded resource URL is malformed.</li>
+<li><bugzilla>55161</bugzilla> - Useless processing in SoapSampler.setPostHeaders. Contributed by Adrian Nistor (nistor1 at illinois.edu)</li>
+<li><bugzilla>54482</bugzilla> - HC fails to follow redirects with non-encoded chars.</li>
+<li><bugzilla>54142</bugzilla> - HTTP(S) Test Script Recorder throws an exception when path contains "|" character.</li>
+<li><bugzilla>55388</bugzilla> - HC3 does not allow IP Source field to override httpclient.localaddress.</li>
+<li><bugzilla>55450</bugzilla> - HEAD redirects should remain as HEAD</li>
+<li><bugzilla>55455</bugzilla> - HTTPS with HTTPClient4 ignores cps setting</li>
+<li><bugzilla>55502</bugzilla> - Proxy generates empty http:/ entries when recording</li>
+<li><bugzilla>55504</bugzilla> - Proxy incorrectly issues CONNECT requests when browser prompts for certificate override</li>
+<li><bugzilla>55506</bugzilla> - Proxy should deliver failed requests to any configured Listeners</li>
+<li><bugzilla>55545</bugzilla> - HTTP(S) Test Script Recorder GUI should not allow both Follow and Auto redirect to be selected</li>
+</ul>
+
+<h3>Other Samplers</h3>
+<ul>
+<li><bugzilla>54913</bugzilla> - JMSPublisherGui incorrectly restores its state. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>55027</bugzilla> - Test Action regression, duration value is not recorded (nightly build).</li>
+<li><bugzilla>55163</bugzilla> - BeanShellTestElement fails to quote string when calling testStarted(String)/testEnded(String).</li>
+<li><bugzilla>55349</bugzilla> - NativeCommand hangs if no input file is specified and the application requests input.</li>
+<li><bugzilla>55462</bugzilla> - System Sampler should not change the sampler label if a sample fails</li>
+</ul>
+
+<h3>Controllers</h3>
+<ul>
+<li><bugzilla>54467</bugzilla> - Loop Controller: compute loop value only once per parent iteration.</li>
+<li><bugzilla>54985</bugzilla> - Make Transaction Controller set Response Code of Generated Parent Sampler to response code of first failing child in case of failure of one of its children. Contributed by Mikhail Epikhin (epihin-m at yandex.ru)</li>
+<li><bugzilla>54950</bugzilla> - ModuleController : Changes to referenced Module are not taken into account if changes occur after first run and referenced node is disabled.</li>
+<li><bugzilla>55201</bugzilla> - ForEach controller excludes start index and includes end index (clarified documentation).</li>
+<li><bugzilla>55334</bugzilla> - Adding Include Controller to test plan (made of Include Controllers) without saving TestPlan leads to included code not being taken into account until save.</li>
+<li><bugzilla>55375</bugzilla> -  StackOverflowError with ModuleController in Non-GUI mode if its name is the same as the target node.</li>
+<li><bugzilla>55464</bugzilla> - Include Controller running included thread group</li>
+</ul>
+
+<h3>Listeners</h3>
+<ul>
+<li><bugzilla>54589</bugzilla> - View Results Tree have a lot of Garbage characters if html page uses double-byte charset.</li>
+<li><bugzilla>54753</bugzilla> - StringIndexOutOfBoundsException at SampleResult.getSampleLabel() if key_on_threadname=false when using Statistical mode.</li>
+<li><bugzilla>54685</bugzilla> - ArrayIndexOutOfBoundsException if "sample_variable" is set in client but not server.</li>
+<li><bugzilla>55111</bugzilla> - ViewResultsTree: text not refitted if vertical scrollbar is required. Contributed by Milamber</li>
+</ul>
+
+<h3>Timers, Assertions, Config, Pre- &amp; Post-Processors</h3>
+<ul>
+<li><bugzilla>54540</bugzilla> - "HTML Parameter Mask" are not marked deprecated in the IHM.</li>
+<li><bugzilla>54575</bugzilla> - CSS/JQuery Extractor : Choosing JODD Implementation always uses JSOUP.</li>
+<li><bugzilla>54901</bugzilla> - Response Assertion GUI behaves weirdly.</li>
+<li><bugzilla>54924</bugzilla> - XMLAssertion uses JMeter JVM file.encoding instead of response encoding and does not clean threadlocal variable.</li>
+<li><bugzilla>53679</bugzilla> -  Constant Throughput Timer bug with localization. Reported by Ludovic Garcia</li>
+</ul>
+
+<h3>Functions</h3>
+<ul>
+<li><bugzilla>55328</bugzilla> - __escapeOroRegexpChars trims spaces.</li>
+</ul>
+
+<h3>I18N</h3>
+<ul>
+<li><bugzilla>55437</bugzilla> - ComboStringEditor does not translate EDIT and UNDEFINED strings on language change</li>
+<li><bugzilla>55501</bugzilla> - Incorrect encoding for French description of __char function. Contributed by Antonio Gomes Rodrigues (ra0077 at gmail.com)</li>
+</ul>
+
+<h3>General</h3>
+<ul>
+<li><bugzilla>54504</bugzilla> - Resource string not found: [clipboard_node_read_error].</li>
+<li><bugzilla>54538</bugzilla> - GUI: context menu is too big.</li>
+<li><bugzilla>54847</bugzilla> - Cut &amp; Paste is broken with tree multi-selection. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54870</bugzilla> - Tree drag and drop may lose leaf nodes (affected nightly build). Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>55056</bugzilla> - wasted work in Data.append(). Contributed by Adrian Nistor (nistor1 at illinois.edu)</li>
+<li><bugzilla>55129</bugzilla> -  Change Javadoc generation per CVE-2013-1571, VU#225657.</li>
+<li><bugzilla>55187</bugzilla> - Integer overflow when computing ONE_YEAR_MS in HTTP CacheManager.</li>
+<li><bugzilla>55208</bugzilla> - JSR223 language entries are duplicated; fold to lower case.</li>
+<li><bugzilla>55203</bugzilla> - TestBeanGUI - wrong language settings found.</li>
+<li><bugzilla>55065</bugzilla> - Useless processing in Spline3.converge(). Contributed by Adrian Nistor (nistor1 at illinois.edu)</li>
+<li><bugzilla>55064</bugzilla> - Useless processing in ReportTreeListener.isValidDragAction(). Contributed by Adrian Nistor (nistor1 at illinois.edu)</li>
+<li><bugzilla>55242</bugzilla> - BeanShell Client jar throws exceptions after upgrading to 2.8.</li>
+<li><bugzilla>55288</bugzilla> - JMeter should default to 0 retries for HTTP requests.</li>
+<li><bugzilla>55405</bugzilla> - ant download_jars task fails if lib/api or lib/doc are missing. Contributed by Antonio Gomes Rodrigues.</li>
+<li><bugzilla>55427</bugzilla> - TestBeanHelper should ignore properties not supported by GenericTestBeanCustomizer</li>
+<li><bugzilla>55459</bugzilla> - Elements using ComboStringEditor lose the input value if user selects another Test Element</li>
+<li><bugzilla>54152</bugzilla> - In distributed testing : activeThreads always show 0 in GUI and Summariser</li>
+<li><bugzilla>55509</bugzilla> - Allow Plugins to be notified of remote thread number progression</li>
+<li><bugzilla>55572</bugzilla> - Detail popup of parameter does not show a Scrollbar when content exceeds display</li>
+</ul>
+
+<!-- =================== Improvements =================== -->
+
+<h2>Improvements</h2>
+
+<h3>HTTP Samplers and Proxy</h3>
+<ul>
+<li>HTTP Request: Small user interaction improvements in Row parameter Detail Box. Contributed by Milamber</li>
+<li><bugzilla>55255</bugzilla> - Allow Body in HTTP DELETE method to support API that use it (like ElasticSearch).</li>
+<li><bugzilla>53480</bugzilla> - Add Kerberos support to Http Sampler (HttpClient4). Based on patch by Felix Schumacher (felix.schumacher at internetallee.de)</li>
+<li><bugzilla>54874</bugzilla> - Support device in addition to source IP address. Based on patch by Dan Fruehauf (malkodan at gmail.com)</li>
+<li><bugzilla>55488</bugzilla> - Add .ico and .woff file extension to default suggested exclusions in proxy recorder. Contributed by Antonio Gomes Rodrigues</li>
+<li><bugzilla>55525</bugzilla> - Proxy should support alias for keyserver entry</li>
+<li><bugzilla>55531</bugzilla> - Proxy recording and redirects. Added code to disable redirected samples.</li>
+</ul>
+
+<h3>Other samplers</h3>
+<ul>
+<li><bugzilla>54788</bugzilla> - JMS Point-to-Point Sampler - GUI enhancements to increase readability and ease of use. Contributed by Bruno Antunes (b.m.antunes at gmail.com)</li>
+<li><bugzilla>54798</bugzilla> - Using subject from EML-file for SMTP Sampler. Contributed by Mikhail Epikhin (epihin-m at yandex.ru)</li>
+<li><bugzilla>54759</bugzilla> - SSLPeerUnverifiedException using HTTPS , property documented.</li>
+<li><bugzilla>54896</bugzilla> - JUnit sampler gives only "failed to create an instance of the class" message with constructor problems.</li>
+<li><bugzilla>55084</bugzilla> - Add timeout support for JDBC Request. Contributed by Mikhail Epikhin (epihin-m at yandex.ru)</li>
+<li><bugzilla>55403</bugzilla> - Enhancement to OS sampler: Support for timeout</li>
+<li><bugzilla>55518</bugzilla> - Add ability to limit number of cached PreparedStatements per connection when "Prepared Select Statement", "Prepared Update Statement" or "Callable Statement" query type is selected</li>
+</ul>
+
+<h3>Controllers</h3>
+<ul>
+<li><bugzilla>54271</bugzilla> - Module Controller breaks if test plan is renamed.</li>
+</ul>
+
+<h3>Listeners</h3>
+<ul>
+<li><bugzilla>54532</bugzilla> - Improve Response Time Graph Y axis scale with huge values or small values (&amp;lt; 1000ms). Add a new field to define increment scale. Contributed by Milamber based on patch by Luca Maragnani (luca.maragnani at gmail.com)</li>
+<li><bugzilla>54576</bugzilla> - View Results Tree : Add a CSS/JQuery Tester.</li>
+<li><bugzilla>54777</bugzilla> - Improve Performance of default ResultCollector. Based on patch by Mikhail Epikhin (epihin-m at yandex.ru)</li>
+<li><bugzilla>55389</bugzilla> - Show IP source address in request data</li>
+</ul>
+
+<h3>Timers, Assertions, Config, Pre- &amp; Post-Processors</h3>
+<ul>
+<li><bugzilla>54789</bugzilla> - XPath Assertion - GUI enhancements to increase readability and ease of use.</li>
+</ul>
+
+<h3>Functions</h3>
+<ul>
+<li><bugzilla>54991</bugzilla> - Add functions to encode/decode URL encoded chars (__urlencode and __urldecode). Contributed by Milamber.</li>
+</ul>
+
+<h3>I18N</h3>
+<ul>
+<li><bugzilla>55241</bugzilla> - Need GUI Editor to process fields which are based on Enums with localised display strings</li>
+<li><bugzilla>55440</bugzilla> - ComboStringEditor should allow tags to be language dependent</li>
+<li><bugzilla>55432</bugzilla> - CSV Dataset Config loses sharing mode when switching languages</li>
+</ul>
+
+<h3>General</h3>
+<ul>
+<li><bugzilla>54584</bugzilla> - MongoDB plugin. Based on patch by Jan Paul Ettles (janpaulettles at gmail.com)</li>
+<li><bugzilla>54669</bugzilla> - Add flag forcing non-GUI JVM to exit after test. Contributed by Scott Emmons</li>
+<li><bugzilla>42428</bugzilla> - Workbench not saved with Test Plan. Contributed by Dzmitry Kashlach (dzmitrykashlach at gmail.com)</li>
+<li><bugzilla>54825</bugzilla> - Add shortcuts to move elements in the tree. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54834</bugzilla> - Improve Drag &amp; Drop in the jmeter tree. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54839</bugzilla> - Set the application name on Mac. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54841</bugzilla> - Correctly handle the quit shortcut on Mac Os (CMD-Q). Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54844</bugzilla> - Set the application icon on Mac Os. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54864</bugzilla> - Enable multi selection drag &amp; drop in the tree without having to start dragging before releasing Shift or Control. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54945</bugzilla> - Add Shutdown Hook to enable trapping kill or CTRL+C signals.</li>
+<li><bugzilla>54990</bugzilla> - Download large files avoiding outOfMemory.</li>
+<li><bugzilla>55085</bugzilla> - UX Improvement : Ability to create New Test Plan from Templates. Contributed by UBIK Load Pack (support at ubikloadpack.com)</li>
+<li><bugzilla>55172</bugzilla> - Provide plugins a way to add Top Menu and menu items.</li>
+<li><bugzilla>55202</bugzilla> - Add syntax color for scripts elements (BeanShell, BSF, and JSR223) and JDBC elements with RSyntaxTextArea. Contributed by Milamber based on patch by Marko Vlahovic (vlahovic74 at gmail.com)</li>
+<li><bugzilla>55175</bugzilla> - HTTPHC4Impl refactoring to allow better inheritance.</li>
+<li><bugzilla>55236</bugzilla> - Templates - provide button to reload template details.</li>
+<li><bugzilla>55237</bugzilla> - Template system should support relative fileName entries.</li>
+<li><bugzilla>55423</bugzilla> - BatchSampleSender: Reduce locking granularity by moving listener.processBatch outside of synchronized block</li>
+<li><bugzilla>55424</bugzilla> - Add Stripping to existing SampleSenders</li>
+<li><bugzilla>55451</bugzilla> - Test Element GUI with JSyntaxTextArea scroll down when text content is long enough to add a Scrollbar</li>
+<li><bugzilla>55513</bugzilla> - StreamCopier cannot be used with System.err or System.out as it closes the output stream</li>
+<li><bugzilla>55514</bugzilla> - SystemCommand should support arbitrary input and output streams</li>
+<li><bugzilla>55515</bugzilla> - SystemCommand should support chaining of commands</li>
+</ul>
+
+<h2>Non-functional changes</h2>
+<ul>
+<li>Updated to jsoup-1.7.2</li>
+<li><bugzilla>54776</bugzilla> - Update the dependency on Bouncy Castle to 1.48. Contributed by Emmanuel Bourg (ebourg at apache.org)</li>
+<li>Updated to HttpComponents Client 4.2.6 (from 4.2.3)</li>
+<li>Updated to HttpComponents Core 4.2.5 (from 4.2.3)</li>
+<li>Updated to commons-codec 1.8 (from 1.6)</li>
+<li>Updated to commons-io 2.4 (from 2.2)</li>
+<li>Updated to commons-logging 1.1.3 (from 1.1.1)</li>
+<li>Updated to commons-net 3.3 (from 3.1)</li>
+<li>Updated to jdom-1.1.3 (from 1.1.2)</li>
+<li>Updated to jodd-lagarto and jodd-core 3.4.4 (from 3.4.1)</li>
+<li>Updated to junit 4.11 (from 4.10)</li>
+<li>Updated to slf4j-api 1.7.5 (from 1.7.2)</li>
+<li>Updated to tika 1.4 (from 1.3)</li>
+<li>Updated to xmlgraphics-commons 1.5 (from 1.3.1)</li>
+<li>Updated to xstream 1.4.4 (from 1.4.2)</li>
+<li>Updated to BouncyCastle 1.49 (from 1.48)</li>
+<li><bugzilla>54912</bugzilla> - JMeterTreeListener should use constants. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
+<li><bugzilla>54903</bugzilla> - Remove the dependency on the Activation Framework. Contributed by Emmanuel Bourg (ebourg at apache.org)</li>
+<li>Moved commons-lang (2.6) to lib/doc as it's only needed by Velocity.</li>
+<li>Re-organised and simplified NOTICE and LICENSE files.</li>
+<li><bugzilla>55411</bugzilla> -  NativeCommand could be useful elsewhere. Copied code to o.a.jorphan.exec.</li>
+<li><bugzilla>55435</bugzilla> - ComboStringEditor could be simplified to make most settings final</li>
+<li><bugzilla>55436</bugzilla> - ComboStringEditor should implement ClearGui</li>
+<li><bugzilla>55463</bugzilla> - Component.requestFocus() is discouraged; use requestFocusInWindow() instead</li>
+<li><bugzilla>55486</bugzilla> - New JMeter Logo. Contributed by UBIK Load Pack (support at ubikloadpack.com)</li>
+<li><bugzilla>55548</bugzilla> - Tidy up use of TestElement.ENABLED; use TestElement.isEnabled()/setEnabled() throughout</li>
+</ul>
+
+<h2>Thanks</h2>
+<p>We thank all contributors mentioned in bug and improvement sections above.<br/>
+We also thank bug reporters who helped us improve JMeter. <br/>
+For this release we want to give special thanks to the following reporters for the clear reports and tests made after our fixes:
+<ul>
+<li>Immanuel Hayden (immanuel.hayden at gmail.com)</li>
+<li>Danny Lade (dlade at web.de)</li>
+<li>Brent Cromarty (brent.cromarty at yahoo.ca)</li>
+<li>Wolfgang Heider (wolfgang.heider at racon.at)</li>
+<li>Shmuel Krakower (shmulikk at gmail.com)</li>
+</ul>
+
+ </p>
+</section> 
+</body> 
+</document>

Propchange: jmeter/trunk/xdocs/Copy of changes.xml
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: jmeter/trunk/xdocs/changes.xml
URL: http://svn.apache.org/viewvc/jmeter/trunk/xdocs/changes.xml?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/xdocs/changes.xml (original)
+++ jmeter/trunk/xdocs/changes.xml Fri Oct  4 19:40:43 2013
@@ -55,12 +55,16 @@ citizen in JMeter, you can now test your
 <figure width="1144" height="638" image="changes/2.10/01_css_jquery_tester.png"></figure>
 </p>
 
-<h4>* Many improvements in HTTP Recording (JMeter Proxy Server) have been made</h4>
-<p><ul>
+<h4>* Many improvements in HTTP(S) Recording have been made</h4>
+<p>
+<note>
+The "HTTP Proxy Server" test element has been renamed as "HTTP(S) Test Script Recorder".
+</note>
+<ul>
 <li>Better recording of HTTPS sites, embedded resources using subdomains will more easily be recorded when using JDK 7</li>
 <li>Redirection are now more smartly detected by HTTP Proxy Server, see <bugzilla>55531</bugzilla></li>
-<li>Many fixes on edgy cases with HTTPS have been made, see <bugzilla>55502</bugzilla>, <bugzilla>55504</bugzilla>, <bugzilla>55506</bugzilla></li>
-<li>Many fixes on edgy encoding have been made, see <bugzilla>54482</bugzilla>, <bugzilla>54142</bugzilla>, <bugzilla>54293</bugzilla></li>
+<li>Many fixes on edge cases with HTTPS have been made, see <bugzilla>55502</bugzilla>, <bugzilla>55504</bugzilla>, <bugzilla>55506</bugzilla></li>
+<li>Many encoding fixes have been made, see <bugzilla>54482</bugzilla>, <bugzilla>54142</bugzilla>, <bugzilla>54293</bugzilla></li>
 </ul>
 </p>
 
@@ -270,7 +274,7 @@ The retry count for the HttpClient 3.1 a
 Previously the default was 1, which could cause unexpected additional traffic.
 </p>
 
-<p>Starting with this version, JMeter Proxy Server tries to detect when a sample is the result of a previous
+<p>Starting with this version, the HTTP(S) Test Script Recorder tries to detect when a sample is the result of a previous
 redirect. If the current response is a redirect, JMeter will save the redirect URL. When the next request is received, 
 it is compared with the saved redirect URL and if there is a match, JMeter will disable the generated sample.
 To revert to previous behaviour, set the property <code>proxy.redirect.disabling=false</code>
@@ -489,6 +493,7 @@ To revert to previous behaviour, set the
 <li><bugzilla>55548</bugzilla> - Tidy up use of TestElement.ENABLED; use TestElement.isEnabled()/setEnabled() throughout</li>
 <li><bugzilla>55617</bugzilla> - Improvements to jorphan collection. Contributed by Benoit Wiart (benoit.wiart at gmail.com)</li>
 <li><bugzilla>55623</bugzilla> - Invalid/unexpected configuration values should not be silently ignored</li>
+<li><bugzilla>55626</bugzilla> - Rename HTTP Proxy Server as HTTP(S) Test Script Recorder</li>
 </ul>
 
 <h2>Thanks</h2>

Modified: jmeter/trunk/xdocs/usermanual/best-practices.xml
URL: http://svn.apache.org/viewvc/jmeter/trunk/xdocs/usermanual/best-practices.xml?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/xdocs/usermanual/best-practices.xml (original)
+++ jmeter/trunk/xdocs/usermanual/best-practices.xml Fri Oct  4 19:40:43 2013
@@ -65,9 +65,9 @@ for information.</p>
 Web Test</a> for information.</p>
 </section>
 
-<section name="&sect-num;.5 Using the Proxy Server" anchor="proxy_server">
-<p>Refer to <complink name="HTTP Proxy Server"/> for details on setting up the proxy
-server. The most important thing to do is filter out all requests you aren't
+<section name="&sect-num;.5 Using the HTTP(S) Test Script Recorder" anchor="proxy_server">
+<p>Refer to <complink name="HTTP(S) Test Script Recorder"/> for details on setting up the
+recorder. The most important thing to do is filter out all requests you aren't
 interested in.  For instance, there's no point in recording image requests (JMeter can
 be instructed to download all images on a page - see <complink name="HTTP Request"/>).
 These will just clutter your test plan.  Most likely, there is an extension all your files
@@ -82,7 +82,7 @@ fresh.</p>
 covered by the Grouping features. include/exclude may still be useful to filter hosts out, so
 that regular browsing with the proxy enabled and the browser configured won't fill your test
 plan with crap. Think about other uses. -->
-<p>The Proxy Server expects to find a ThreadGroup element with a Recording Controller
+<p>The HTTP(S) Test Script Recorder expects to find a ThreadGroup element with a Recording Controller
 under it where it will record HTTP Requests to.  This conveniently packages all your samples under one
 controller, which can be given a name that describes the test case.</p><!--TODO: is this best practice? I don't think so!-->
 <p>Now, go through the steps of a Test Case.  If you have no pre-defined test cases, use
@@ -91,7 +91,7 @@ definite series of steps, save the entir
 clean and start a new test case.  By doing this, you can quickly record a large number of
 test case "rough drafts".</p><!--TODO: no need to wipe out now - you can create a new controller and
 resume recording into it-->
-<p>One of the most useful features of the Proxy Server is that you can abstract out
+<p>One of the most useful features of the HTTP(S) Test Script Recorder is that you can abstract out
 certain common elements from the recorded samples.  By defining some
 <a href="functions.html">user-defined variables</a> at the Test Plan level or in
 <complink name="User Defined Variables"/> elements, you can have JMeter automatically

Modified: jmeter/trunk/xdocs/usermanual/component_reference.xml
URL: http://svn.apache.org/viewvc/jmeter/trunk/xdocs/usermanual/component_reference.xml?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/xdocs/usermanual/component_reference.xml (original)
+++ jmeter/trunk/xdocs/usermanual/component_reference.xml Fri Oct  4 19:40:43 2013
@@ -122,7 +122,7 @@ Latency is set to the time it takes to l
         HTTP Request.</p>
 
         <p>Or, instead of manually adding HTTP Requests, you may want to use
-        JMeter's <complink name="HTTP Proxy Server"/> to create
+        JMeter's <complink name="HTTP(S) Test Script Recorder"/> to create
         them.  This can save you time if you have a lot of HTTP requests or requests with many
         parameters.</p>
 
@@ -453,7 +453,7 @@ httpclient3.retrycount=3
         <complink name="HTTP Cookie Manager"/>
         <complink name="HTTP Header Manager"/>
         <complink name="HTML Link Parser"/>
-        <complink name="HTTP Proxy Server"/>
+        <complink name="HTTP(S) Test Script Recorder"/>
         <complink name="HTTP Request Defaults"/>
         <link href="build-adv-web-test-plan.html#session_url_rewriting">HTTP Requests and Session ID's: URL Rewriting</link>
 </links>
@@ -2496,7 +2496,7 @@ attempts to open the fileName relative t
 <description>
 <p>The Recording Controller is a place holder indicating where the proxy server should
 record samples to.  During test run, it has no effect, similar to the Simple Controller.  But during
-recording using the <complink name="HTTP Proxy Server" />, all recorded samples will by default
+recording using the <complink name="HTTP(S) Test Script Recorder" />, all recorded samples will by default
 be saved under the Recording Controller.</p>
 
 </description>
@@ -5657,7 +5657,7 @@ Your WorkBench can be saved independentl
         </property>
 </properties>
 <ul>
-<li><complink name="HTTP Proxy Server"/></li>
+<li><complink name="HTTP(S) Test Script Recorder"/></li>
 <li><complink name="HTTP Mirror Server"/></li>
 <li><complink name="Property Display"/></li>
 </ul>
@@ -5712,14 +5712,14 @@ Your WorkBench can be saved independentl
 </p>
 </component>
 
-<component name="HTTP Proxy Server" index="&sect-num;.9.5"  width="957" height="593" screenshot="proxy_control.png">
-<description><p>The Proxy Server allows JMeter to watch and record your actions while you browse your web application
+<component name="HTTP(S) Test Script Recorder" was="HTTP Proxy Server" index="&sect-num;.9.5"  width="957" height="593" screenshot="proxy_control.png">
+<description><p>The HTTP(S) Test Script Recorder allows JMeter to watch and record your actions while you browse your web application
 with your normal browser.  JMeter will create test sample objects and store them
 directly into your test plan as you go (so you can view samples interactively while you make them).</p>
 
-<p>To use the proxy server, <i>add</i> the HTTP Proxy Server element to the workbench.
+<p>To use the proxy server, <i>add</i> the HTTP(S) Test Script Recorder element to the workbench.
 Select the WorkBench element in the tree, and right-click on this element to get the
-Add menu (Add --> Non-Test Elements --> HTTP Proxy Server).</p>
+Add menu (Add --> Non-Test Elements --> HTTP(S) Test Script Recorder).</p>
 <p>
 You also need to set up your browser to use the JMeter proxy port as the proxy for HTTP and HTTPS requests.
 Do not use JMeter as the proxy for any other request types - FTP, etc. - as the JMeter proxy cannot handle them.
@@ -5777,7 +5777,7 @@ This setting will also be needed when ru
 
 <properties>
         <property name="Name" required="No">Descriptive name for this element that is shown in the tree.</property>
-        <property name="Port" required="Yes">The port that the Proxy Server listens to.  8080 is the default, but you can change it.</property>
+        <property name="Port" required="Yes">The port that the HTTP(S) Test Script Recorder listens to.  8080 is the default, but you can change it.</property>
         <property name="Target Controller" required="Yes">The controller where the proxy will store the generated samples. By default, it will look for a Recording Controller and store them there wherever it is.</property>
         <property name="Grouping" required="Yes">Whether to group samplers for requests from a single "click" (requests received without significant time separation), and how to represent that grouping in the recording:
            <ul>
@@ -5891,7 +5891,7 @@ proxy.binary.filesuffix=.binary
 
 <h4>Adding timers</h4>
 <p>It is also possible to have the proxy add timers to the recorded script. To
-do this, create a timer directly within the HTTP Proxy Server component.
+do this, create a timer directly within the HTTP(S) Test Script Recorder component.
 The proxy will place a copy of this timer into each sample it records, or into
 the first sample of each group if you're using grouping. This copy will then be
 scanned for occurences of variable ${T} in its properties, and any such
@@ -5921,19 +5921,19 @@ try using the non-loopback hostname or I
 </p>
 
 <h4>Handling of HTTP Request Defaults</h4>
-<p>If the HTTP Proxy Server finds enabled <complink name="HTTP Request Defaults"/> directly within the
+<p>If the HTTP(S) Test Script Recorder finds enabled <complink name="HTTP Request Defaults"/> directly within the
 controller where samples are being stored, or directly within any of its parent controllers, the recorded samples
 will have empty fields for the default values you specified. You may further control this behaviour by placing an
-HTTP Request Defaults element directly within the HTTP Proxy Server, whose non-blank values will override
+HTTP Request Defaults element directly within the HTTP(S) Test Script Recorder, whose non-blank values will override
 those in the other HTTP Request Defaults. See <a href="best-practices.html#proxy_server"> Best
-Practices with the Proxy Server</a> for more info.</p>
+Practices with the HTTP(S) Test Script Recorder</a> for more info.</p>
 
 <h4>User Defined Variable replacement</h4>
-<p>Similarly, if the HTTP Proxy Server finds <complink name="User Defined Variables"/> (UDV) directly within the
+<p>Similarly, if the HTTP(S) Test Script Recorder finds <complink name="User Defined Variables"/> (UDV) directly within the
 controller where samples are being stored, or directly within any of its parent controllers, the recorded samples
 will have any occurences of the values of those variables replaced by the corresponding variable. Again, you can
-place User Defined Variables directly within the HTTP Proxy Server to override the values to be replaced. See
-<a href="best-practices.html#proxy_server"> Best Practices with the Proxy Server</a> for more info.</p>
+place User Defined Variables directly within the HTTP(S) Test Script Recorder to override the values to be replaced. See
+<a href="best-practices.html#proxy_server"> Best Practices with the Test Script Recorder</a> for more info.</p>
 
 <note>Please note that matching is case-sensitive.</note>
 
@@ -5958,7 +5958,7 @@ your browser's proxy settings.  Now, you
 cookie manager, etc.</p>
 
 <h4>How can I record the server's responses too?</h4>
-<p>Just place a <complink name="View Results Tree"/> listener as a child of the Proxy Server and the responses will be displayed. 
+<p>Just place a <complink name="View Results Tree"/> listener as a child of the HTTP(S) Test Script Recorder and the responses will be displayed. 
 You can also add a <complink name="Save Responses to a file"/> Post-Processor which will save the responses to files.
 </p>
 

Modified: jmeter/trunk/xdocs/usermanual/get-started.xml
URL: http://svn.apache.org/viewvc/jmeter/trunk/xdocs/usermanual/get-started.xml?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/xdocs/usermanual/get-started.xml (original)
+++ jmeter/trunk/xdocs/usermanual/get-started.xml Fri Oct  4 19:40:43 2013
@@ -285,7 +285,7 @@ and the java command silently ignores th
 [This occurs with all Java programs, not just JMeter.]</p>
 </subsection>
 
-<subsection name="&sect-num;.4.2 Using a Proxy Server" anchor="proxy_server">
+<subsection name="&sect-num;.4.2 Using a HTTP(S) Test Script Recorder" anchor="proxy_server">
 <p>If you are testing from behind a firewall/proxy server, you may need to provide JMeter with
 the firewall/proxy server hostname and port number.  To do so, run the jmeter[.bat] file
 from a command line with the following parameters:</p>
@@ -321,8 +321,8 @@ you can define the relevant properties i
 Proxy Settings can also be defined in a Test Plan, using either the <complink name="HTTP Request Defaults"/>
 configuration or the <complink name="HTTP Request"/> sampler elements.
 </p>
-<note>JMeter also has its own in-built <complink name="HTTP Proxy Server">HTTP Proxy Server</complink>,
-which can be used for recording HTTP or HTTPS browser sessions.
+<note>JMeter also has its own in-built Proxy Server, the <complink name="HTTP(S) Test Script Recorder">HTTP(S) Test Script Recorder</complink>.
+This is only used for recording HTTP or HTTPS browser sessions.
 This is not to be confused with the proxy settings described above, which are used when JMeter makes HTTP or HTTPS requests itself.</note>
 </subsection>
 

Modified: jmeter/trunk/xdocs/usermanual/index.xml
URL: http://svn.apache.org/viewvc/jmeter/trunk/xdocs/usermanual/index.xml?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/xdocs/usermanual/index.xml (original)
+++ jmeter/trunk/xdocs/usermanual/index.xml Fri Oct  4 19:40:43 2013
@@ -177,7 +177,7 @@
      <li><a href="best-practices.html#limit_threads">16.1 Limit the Number of Threads</a></li>
      <li><a href="best-practices.html#put_cookie_manager">16.2 Where to Put the Cookie Manager</a></li>
      <li><a href="best-practices.html#put_auth_manager">16.3 Where to Put the Authorization Manager</a></li>
-     <li><a href="best-practices.html#proxy_server">16.4 Using the Proxy Server to record test scripts</a></li>
+     <li><a href="best-practices.html#proxy_server">16.4 Using the HTTP(S) Test Script Recorder to record test scripts</a></li>
      <li><a href="best-practices.html#user_variables">16.5 User variables</a></li>
      <li><a href="best-practices.html#lean_mean">16.6 Reducing resource requirements</a></li>
      <li><a href="best-practices.html#beanshell_server">16.7 BeanShell server</a></li>

Modified: jmeter/trunk/xdocs/usermanual/test_plan.xml
URL: http://svn.apache.org/viewvc/jmeter/trunk/xdocs/usermanual/test_plan.xml?rev=1529274&r1=1529273&r2=1529274&view=diff
==============================================================================
--- jmeter/trunk/xdocs/usermanual/test_plan.xml (original)
+++ jmeter/trunk/xdocs/usermanual/test_plan.xml Fri Oct  4 19:40:43 2013
@@ -308,7 +308,7 @@ and will count towards the error %age fo
 
 <subsection name="&sect-num;.6 Configuration Elements" anchor="config_elements">
 <p>A configuration element works closely with a Sampler.  Although it does not send requests
-(except for <complink name="HTTP Proxy Server"/>), it can add to or modify requests.</p>
+(except for <complink name="HTTP(S) Test Script Recorder"/>), it can add to or modify requests.</p>
 
 <p>A configuration element is accessible from only inside the tree branch where you place the element.
 For example, if you place an HTTP Cookie Manager inside a Simple Logic Controller, the Cookie Manager will
--- jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java (original)
+++ jmeter/trunk/src/protocol/http/org/apache/jmeter/protocol/http/proxy/ProxyControl.java Fri Oct  4 19:40:43 2013
@@ -210,14 +210,14 @@ public class ProxyControl extends Generi
     static {
         if (CERT_ALIAS != null) {
             KEYSTORE_MODE = KeystoreMode.USER_KEYSTORE;
-            log.info("Proxy Server will use the keystore '"+ CERT_PATH_ABS + "' with the alias: '" + CERT_ALIAS + "'");
+            log.info("HTTP(S) Test Script Recorder will use the keystore '"+ CERT_PATH_ABS + "' with the alias: '" + CERT_ALIAS + "'");
         } else {
             if (KeyToolUtils.SUPPORTS_HOST_CERT && USE_DYNAMIC_KEYS) {
                 KEYSTORE_MODE = KeystoreMode.DYNAMIC_KEYSTORE;
-                log.info("Proxy Server SSL Proxy will use keys that support embedded 3rd party resources in file " + CERT_PATH_ABS);
+                log.info("HTTP(S) Test Script Recorder SSL Proxy will use keys that support embedded 3rd party resources in file " + CERT_PATH_ABS);
             } else {
                 KEYSTORE_MODE = KeystoreMode.JMETER_KEYSTORE;
-                log.warn("Proxy Server SSL Proxy will use keys that may not work for embedded resources in file " + CERT_PATH_ABS);
+                log.warn("HTTP(S) Test Script Recorder SSL Proxy will use keys that may not work for embedded resources in file " + CERT_PATH_ABS);
             }
         }
     }
@@ -867,7 +867,7 @@ public class ProxyControl extends Generi
      * Finds all configuration objects of the given class applicable to the
      * recorded samplers, that is:
      * <ul>
      * <li>All such elements directly within the HTTP Proxy Server (these have
      * the highest priority).
      * <li>All such elements directly within the target controller (higher
      * priority) or directly within any containing controller (lower priority),
@@ -1211,7 +1211,7 @@ public class ProxyControl extends Generi
         case USER_KEYSTORE:
             storePassword = JMeterUtils.getPropDefault("proxy.cert.keystorepass", DEFAULT_PASSWORD); // $NON-NLS-1$;
             keyPassword = JMeterUtils.getPropDefault("proxy.cert.keypassword", DEFAULT_PASSWORD); // $NON-NLS-1$;
-            log.info("Proxy Server will use the keystore '"+ CERT_PATH_ABS + "' with the alias: '" + CERT_ALIAS + "'");
+            log.info("HTTP(S) Test Script Recorder will use the keystore '"+ CERT_PATH_ABS + "' with the alias: '" + CERT_ALIAS + "'");
             initUserKeyStore();
             break;
         default:
@@ -867,7 +867,7 @@ public class ProxyControl extends Generi
      * recorded samplers, that is:
      * <ul>
-     * <li>All such elements directly within the HTTP Proxy Server (these have
+     * <li>All such elements directly within the HTTP(S) Test Script Recorder (these have
      * the highest priority).
      * <li>All such elements directly within the target controller (higher

Added: jmeter/trunk/xdocs/Copy (2) of changes.xml
URL: http://svn.apache.org/viewvc/jmeter/trunk/xdocs/Copy%20%282%29%20of%20changes.xml?rev=1529274&view=auto
==============================================================================